#[repr(i32)]pub enum Value {
Unknown = 0,
FastCdc2020 = 1,
RepMaxCdc = 2,
}Variants
Unknown = 0
No specific algorithm. Servers MUST always accept this value. For GetChunkMapping, the server chooses the algorithm. For RegisterChunkMapping, the server only verifies that chunks concatenate to form the expected blob.
FastCdc2020 = 1
The FastCDC chunking algorithm as described in the 2020 paper by Wen Xia, et al. See https://ieeexplore.ieee.org/document/9055082 for details.
RepMaxCdc = 2
The RepMaxCDC chunking algorithm as implemented by buildbarn/go-cdc. See https://github.com/buildbarn/go-cdc for details.
Implementations
Sourceimpl Value
impl Value
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.